@@ -291,6 +291,7 @@ def FieldDetermination(Fields):
     import numpy as np
     import pandas as pd
 
+    null = .001
     fields = pd.DataFrame(columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
     for i in range(Fields):
         print('Enter the object type '+ str(i+1) + " (0 - circular, 1 - rectangular):")
@@ -302,7 +303,7 @@ def FieldDetermination(Fields):
             centerY = int(input())
             print('Enter the radius value of the field ' + str(i+1) + ':')
             radius = int(input())
-            df2 = pd.DataFrame([[objectType, centerX, centerY,radius,'null','null','null','null']], columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
+            df2 = pd.DataFrame([[objectType, centerX, centerY,radius,null,null,null,null]], columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
         else:
             print('Enter the X value of the field\'s lower left vertex ' + str(i+1) + ':')
             aX = int(input())
@@ -312,7 +313,7 @@ def FieldDetermination(Fields):
             height = int(input())
             print('Enter the field\'s width value ' + str(i+1) + ':')
             width = int(input())
-            df2 = pd.DataFrame([[objectType, 'null','null' , 'null' ,aX,aY,height,width]], columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
+            df2 = pd.DataFrame([[objectType, null,null, null ,aX,aY,height,width]], columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
         fields = fields.append(df2, ignore_index=True)
         
     return fields
